Package: rgbIndices
Type: Package
Title: RGB Visible Indices for Image Analysis
Version: 0.1.1
Authors@R: c(person("RN", "Singh", role = "aut"), person("Bappa", "Das", role = "aut"), person("Sonam", role = "aut"), person("Anil", "Kumar", role = "aut"), person("Santosha", "Rathod", email = "santoshagriculture@gmail.com", role = c("aut", "cre")))
Description: Computes RGB-based vegetation, color, and spectral indices from digital images for applications in agriculture, crop phenotyping, and remote sensing. The methods are based on digital image processing and plant phenotyping approaches (Singh et al. (2023) <doi:10.1080/10106049.2022.2160831>).
License: MIT + file LICENSE
Encoding: UTF-8
Imports: raster, tibble
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-28 11:29:58 UTC; Admin
Author: RN Singh [aut],
  Bappa Das [aut],
  Sonam [aut],
  Anil Kumar [aut],
  Santosha Rathod [aut, cre]
Maintainer: Santosha Rathod <santoshagriculture@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-29 07:40:02 UTC
Built: R 4.6.0; ; 2026-05-01 21:22:24 UTC; unix
