# Generated by roxygen2: do not edit by hand

export(rgb_basic)
export(rgb_color)
export(rgb_diff)
export(rgb_example)
export(rgb_indices_to_mean)
export(rgb_indices_to_tbl)
export(rgb_normdiff)
export(rgb_ratio)
export(rgb_veg)
