% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_normdiff.R
\name{rgb_normdiff}
\alias{rgb_normdiff}
\title{RGB normalized difference indices}
\usage{
rgb_normdiff(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a normalized difference
between RGB bands: NRGDI ((R - G)/(R + G + B)), NRBDI ((R - B)/(R + G + B)),
NGBDI ((G - B)/(R + G + B)), NGRDI ((G - R)/(R + G + B)),
NBGDI ((B - G)/(R + G + B)), and NBRDI ((B - R)/(R + G + B)).
}
\description{
Computes normalized difference indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_normdiff(img)

}
