% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_veg.R
\name{rgb_veg}
\alias{rgb_veg}
\title{RGB vegetation indices}
\usage{
rgb_veg(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object containing multiple vegetation indices derived from RGB bands.
Each layer corresponds to a specific vegetation index, including:
WI, GRVI, IKAW, NDTI, GBI, GLI, VARI, NDI, ExG, ExR, ExGR, MxEG, ExB, and RGBVI.
}
\description{
Computes vegetation-related indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_veg(img)

}
