% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_color.R
\name{rgb_color}
\alias{rgb_color}
\title{RGB color indices}
\usage{
rgb_color(image)
}
\arguments{
\item{image}{A RasterBrick or RasterStack object with three bands (R, G, B).}
}
\value{
A RasterStack object where each layer represents a specific RGB-based color index,
including Grey, BI, HI, RI, SI, CI, CIVE, VEG, IPCA, GLAI, SAT, OHI, TCVI, COM1, and COM2.
}
\description{
Computes multiple RGB-based color indices from a three-band RGB image.
}
\examples{
set.seed(123)
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
rgb_color(img)

}
