% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rgb_indices_to_mean.R
\name{rgb_indices_to_mean}
\alias{rgb_indices_to_mean}
\title{Mean RGB indices}
\usage{
rgb_indices_to_mean(x)
}
\arguments{
\item{x}{A RasterBrick or RasterStack object containing RGB indices.}
}
\value{
A tibble (data frame) with a single row where each column represents
the mean value of an RGB index computed across all pixels.
}
\description{
Computes the mean values of RGB-based indices from a RasterBrick or RasterStack object.
}
\details{
The function calculates the mean of each layer in the input raster object
using \code{raster::cellStats}. The output provides a summary of the indices
for the entire image.
}
\examples{
r <- raster::raster(matrix(runif(50*50), 50, 50))
g <- raster::raster(matrix(runif(50*50), 50, 50))
b <- raster::raster(matrix(runif(50*50), 50, 50))
img <- raster::stack(r, g, b)
x <- rgb_basic(img)

rgb_indices_to_mean(x)

}
